@@ -61,6 +61,7 @@ class UserProfile:
     gender: Gender
     home_address: Address
     work_address: Address
+    zone_id: Optional[str] = None
     dob: Optional[datetime] = None
     email: Optional[str] = None
     img_url: Optional[str] = None
@@ -76,6 +77,7 @@ class UserProfile:
             user_id=_dict["id"],
             name=_dict.get("name"),
             gender=Gender(_dict["gender"]) if _dict.get("gender") else None,
+            zone_id=_dict.get("zone_id"),
             home_address=Address.from_dict(_dict["home_address"])
             if _dict.get("home_address")
             else None,
@@ -101,6 +103,8 @@ class UserProfile:
             "work_address": self.work_address.to_dict(),
         }
 
+        if self.zone_id:
+            rv["zone_id"] = self.zone_id
         if self.dob:
             rv["dob"] = self.dob
         if self.email:
